@@ -2,10 +2,13 @@ module Database.HDBC.PostgreSQL.Types
 where
 
 import Foreign
+import Control.Concurrent.MVar
+
+type ConnLock = MVar ()
 
 data CConn = CConn
 type WrappedCConn = Ptr CConn
-type Conn = ForeignPtr WrappedCConn
+type Conn = (ConnLock, ForeignPtr WrappedCConn)
 
 data CStmt = CStmt
 type WrappedCStmt = Ptr CStmt
